# Generated by roxygen2: do not edit by hand

S3method(as.data.frame,gp3bayes_analysis_bundle)
S3method(as.data.frame,gp3bayes_analysis_manifest)
S3method(as.data.frame,gp3bayes_backend_environment)
S3method(as.data.frame,gp3bayes_backend_parity_audit)
S3method(as.data.frame,gp3bayes_binocular_pupil_audit)
S3method(as.data.frame,gp3bayes_design_support_audit)
S3method(as.data.frame,gp3bayes_fixed_effect_design_audit)
S3method(as.data.frame,gp3bayes_gazepoint_pupil_schema)
S3method(as.data.frame,gp3bayes_group_prediction_check)
S3method(as.data.frame,gp3bayes_loo_influence_atlas)
S3method(as.data.frame,gp3bayes_manifest_comparison)
S3method(as.data.frame,gp3bayes_mcmc_quality)
S3method(as.data.frame,gp3bayes_missingness_audit)
S3method(as.data.frame,gp3bayes_model_card)
S3method(as.data.frame,gp3bayes_model_evidence)
S3method(as.data.frame,gp3bayes_object_validation)
S3method(as.data.frame,gp3bayes_prediction)
S3method(as.data.frame,gp3bayes_prediction_support)
S3method(as.data.frame,gp3bayes_prediction_uncertainty)
S3method(as.data.frame,gp3bayes_prior_posterior_bridge)
S3method(as.data.frame,gp3bayes_pupil_advanced_diagnostics)
S3method(as.data.frame,gp3bayes_pupil_advanced_sensitivity_suite)
S3method(as.data.frame,gp3bayes_pupil_advanced_specification)
S3method(as.data.frame,gp3bayes_pupil_advanced_trajectory)
S3method(as.data.frame,gp3bayes_pupil_autocorrelation_comparison)
S3method(as.data.frame,gp3bayes_pupil_complexity_audit)
S3method(as.data.frame,gp3bayes_pupil_contract)
S3method(as.data.frame,gp3bayes_pupil_diagnostics)
S3method(as.data.frame,gp3bayes_pupil_dynamic_contrast)
S3method(as.data.frame,gp3bayes_pupil_estimand)
S3method(as.data.frame,gp3bayes_pupil_gp_hyperparameters)
S3method(as.data.frame,gp3bayes_pupil_identifiability_audit)
S3method(as.data.frame,gp3bayes_pupil_lfo_comparison)
S3method(as.data.frame,gp3bayes_pupil_lfo_plan)
S3method(as.data.frame,gp3bayes_pupil_measurement_audit)
S3method(as.data.frame,gp3bayes_pupil_measurement_audit_05)
S3method(as.data.frame,gp3bayes_pupil_missingness_audit)
S3method(as.data.frame,gp3bayes_pupil_model_card)
S3method(as.data.frame,gp3bayes_pupil_model_comparison)
S3method(as.data.frame,gp3bayes_pupil_model_specification)
S3method(as.data.frame,gp3bayes_pupil_posterior_summary)
S3method(as.data.frame,gp3bayes_pupil_ppc)
S3method(as.data.frame,gp3bayes_pupil_predictive_score)
S3method(as.data.frame,gp3bayes_pupil_prior_predictive)
S3method(as.data.frame,gp3bayes_pupil_readiness)
S3method(as.data.frame,gp3bayes_pupil_residual_scale)
S3method(as.data.frame,gp3bayes_pupil_residual_spectrum)
S3method(as.data.frame,gp3bayes_pupil_response_parameters)
S3method(as.data.frame,gp3bayes_pupil_sensitivity)
S3method(as.data.frame,gp3bayes_pupil_temporal_dependence_audit)
S3method(as.data.frame,gp3bayes_pupil_threshold_duration)
S3method(as.data.frame,gp3bayes_pupil_trajectory)
S3method(as.data.frame,gp3bayes_pupil_trajectory_derivative)
S3method(as.data.frame,gp3bayes_pupil_validation)
S3method(as.data.frame,gp3bayes_random_effects_support_audit)
S3method(as.data.frame,gp3bayes_schema_comparison)
S3method(as.data.frame,gp3bayes_sensitivity_suite)
S3method(plot,gp3bayes_analysis_manifest)
S3method(plot,gp3bayes_backend_environment)
S3method(plot,gp3bayes_backend_parity_audit)
S3method(plot,gp3bayes_binary_group_variation)
S3method(plot,gp3bayes_binary_ppc_detail)
S3method(plot,gp3bayes_condition_balance)
S3method(plot,gp3bayes_design_support_audit)
S3method(plot,gp3bayes_diagnostic_dashboard)
S3method(plot,gp3bayes_duration_boundary_audit)
S3method(plot,gp3bayes_duration_extreme_review)
S3method(plot,gp3bayes_duration_ppc_detail)
S3method(plot,gp3bayes_estimand)
S3method(plot,gp3bayes_estimand_sensitivity)
S3method(plot,gp3bayes_fixed_effect_design_audit)
S3method(plot,gp3bayes_group_prediction_check)
S3method(plot,gp3bayes_identifier_predictor_audit)
S3method(plot,gp3bayes_kfold_cv)
S3method(plot,gp3bayes_loo_influence_atlas)
S3method(plot,gp3bayes_manifest_comparison)
S3method(plot,gp3bayes_missingness_audit)
S3method(plot,gp3bayes_model_evidence)
S3method(plot,gp3bayes_pathological_simulation)
S3method(plot,gp3bayes_powerscale_sensitivity)
S3method(plot,gp3bayes_prediction)
S3method(plot,gp3bayes_prediction_uncertainty)
S3method(plot,gp3bayes_prior_posterior_bridge)
S3method(plot,gp3bayes_psis_loo)
S3method(plot,gp3bayes_random_effects_support_audit)
S3method(plot,gp3bayes_sbc_result)
S3method(plot,gp3bayes_schema_comparison)
S3method(plot,gp3bayes_sensitivity_suite)
S3method(plot,gp3bayes_separation_screen)
S3method(plot,gp3bayes_strict_readiness_audit)
S3method(plot,gp3bayes_transformation_replay_audit)
S3method(plot,gp3bayes_workflow_status)
S3method(print,gp3bayes_analysis_bundle)
S3method(print,gp3bayes_analysis_manifest)
S3method(print,gp3bayes_backend_capabilities)
S3method(print,gp3bayes_backend_capabilities_v2)
S3method(print,gp3bayes_backend_environment)
S3method(print,gp3bayes_backend_parity_audit)
S3method(print,gp3bayes_backend_portable_fit)
S3method(print,gp3bayes_binary_backend_specification)
S3method(print,gp3bayes_binary_calibration_uncertainty)
S3method(print,gp3bayes_binary_fit)
S3method(print,gp3bayes_binary_group_variation)
S3method(print,gp3bayes_binary_model_specification)
S3method(print,gp3bayes_binary_posterior_summary)
S3method(print,gp3bayes_binary_prepared)
S3method(print,gp3bayes_binary_prior_predictive_check)
S3method(print,gp3bayes_binary_simulation)
S3method(print,gp3bayes_binocular_pupil_audit)
S3method(print,gp3bayes_binocular_pupil_fit)
S3method(print,gp3bayes_binocular_pupil_prepared)
S3method(print,gp3bayes_binocular_pupil_simulation)
S3method(print,gp3bayes_binocular_pupil_specification)
S3method(print,gp3bayes_binocular_pupil_trajectory)
S3method(print,gp3bayes_cmdstan_backend_audit)
S3method(print,gp3bayes_condition_balance)
S3method(print,gp3bayes_design_support_audit)
S3method(print,gp3bayes_diagnostic_dashboard)
S3method(print,gp3bayes_duration_backend_specification)
S3method(print,gp3bayes_duration_boundary_audit)
S3method(print,gp3bayes_duration_extreme_review)
S3method(print,gp3bayes_duration_fit)
S3method(print,gp3bayes_duration_model_specification)
S3method(print,gp3bayes_duration_posterior_summary)
S3method(print,gp3bayes_duration_prepared)
S3method(print,gp3bayes_duration_prior_predictive_check)
S3method(print,gp3bayes_duration_simulation)
S3method(print,gp3bayes_estimand)
S3method(print,gp3bayes_estimand_sensitivity)
S3method(print,gp3bayes_evidence_inventory)
S3method(print,gp3bayes_figure_set)
S3method(print,gp3bayes_fixed_effect_design_audit)
S3method(print,gp3bayes_gazepoint_pupil_schema)
S3method(print,gp3bayes_group_deletion_sensitivity_plan)
S3method(print,gp3bayes_group_prediction_check)
S3method(print,gp3bayes_identifier_predictor_audit)
S3method(print,gp3bayes_kfold_cv)
S3method(print,gp3bayes_loo_comparison)
S3method(print,gp3bayes_loo_influence_atlas)
S3method(print,gp3bayes_loo_weights)
S3method(print,gp3bayes_manifest_comparison)
S3method(print,gp3bayes_manifest_validation)
S3method(print,gp3bayes_mcmc_quality)
S3method(print,gp3bayes_missingness_audit)
S3method(print,gp3bayes_model_card)
S3method(print,gp3bayes_model_contract)
S3method(print,gp3bayes_model_evidence)
S3method(print,gp3bayes_model_report)
S3method(print,gp3bayes_model_specification)
S3method(print,gp3bayes_object_schema)
S3method(print,gp3bayes_object_validation)
S3method(print,gp3bayes_pathological_simulation)
S3method(print,gp3bayes_pathology_evaluation)
S3method(print,gp3bayes_posterior_predictive_check)
S3method(print,gp3bayes_powerscale_sensitivity)
S3method(print,gp3bayes_ppc_statistic)
S3method(print,gp3bayes_prediction)
S3method(print,gp3bayes_prediction_score_uncertainty)
S3method(print,gp3bayes_prediction_support)
S3method(print,gp3bayes_prediction_uncertainty)
S3method(print,gp3bayes_predictive_distribution_atlas)
S3method(print,gp3bayes_prior_posterior_bridge)
S3method(print,gp3bayes_prior_sensitivity)
S3method(print,gp3bayes_prior_specification)
S3method(print,gp3bayes_psis_loo)
S3method(print,gp3bayes_publication_registry)
S3method(print,gp3bayes_publication_registry_validation)
S3method(print,gp3bayes_pupil_advanced_brms_specification)
S3method(print,gp3bayes_pupil_advanced_diagnostics)
S3method(print,gp3bayes_pupil_advanced_fit)
S3method(print,gp3bayes_pupil_advanced_prior_predictive)
S3method(print,gp3bayes_pupil_advanced_sensitivity_suite)
S3method(print,gp3bayes_pupil_advanced_simulation)
S3method(print,gp3bayes_pupil_advanced_specification)
S3method(print,gp3bayes_pupil_advanced_trajectory)
S3method(print,gp3bayes_pupil_autocorrelation_comparison)
S3method(print,gp3bayes_pupil_complexity_audit)
S3method(print,gp3bayes_pupil_contract)
S3method(print,gp3bayes_pupil_diagnostics)
S3method(print,gp3bayes_pupil_distribution_spec)
S3method(print,gp3bayes_pupil_dynamic_contrast)
S3method(print,gp3bayes_pupil_estimand)
S3method(print,gp3bayes_pupil_fit)
S3method(print,gp3bayes_pupil_gp_hyperparameters)
S3method(print,gp3bayes_pupil_identifiability_audit)
S3method(print,gp3bayes_pupil_lfo_comparison)
S3method(print,gp3bayes_pupil_lfo_plan)
S3method(print,gp3bayes_pupil_lfo_validation)
S3method(print,gp3bayes_pupil_measurement_audit_05)
S3method(print,gp3bayes_pupil_missingness_audit)
S3method(print,gp3bayes_pupil_model_card)
S3method(print,gp3bayes_pupil_model_comparison)
S3method(print,gp3bayes_pupil_model_set)
S3method(print,gp3bayes_pupil_model_specification)
S3method(print,gp3bayes_pupil_posterior_summary)
S3method(print,gp3bayes_pupil_ppc)
S3method(print,gp3bayes_pupil_predictive_calibration)
S3method(print,gp3bayes_pupil_predictive_score)
S3method(print,gp3bayes_pupil_prepared)
S3method(print,gp3bayes_pupil_prior_predictive)
S3method(print,gp3bayes_pupil_readiness)
S3method(print,gp3bayes_pupil_residual_scale)
S3method(print,gp3bayes_pupil_residual_spectrum)
S3method(print,gp3bayes_pupil_response_parameters)
S3method(print,gp3bayes_pupil_response_shape_fit)
S3method(print,gp3bayes_pupil_response_shape_specification)
S3method(print,gp3bayes_pupil_sensitivity)
S3method(print,gp3bayes_pupil_simulation)
S3method(print,gp3bayes_pupil_temporal_dependence_audit)
S3method(print,gp3bayes_pupil_threshold_duration)
S3method(print,gp3bayes_pupil_trajectory_derivative)
S3method(print,gp3bayes_pupil_validation)
S3method(print,gp3bayes_pupil_validation_plan)
S3method(print,gp3bayes_random_effects_support_audit)
S3method(print,gp3bayes_random_intercept_variance_partition)
S3method(print,gp3bayes_random_slope_sensitivity_plan)
S3method(print,gp3bayes_readiness_audit)
S3method(print,gp3bayes_recovery)
S3method(print,gp3bayes_sampling_diagnostics)
S3method(print,gp3bayes_sbc_plan)
S3method(print,gp3bayes_sbc_result)
S3method(print,gp3bayes_schema_comparison)
S3method(print,gp3bayes_schema_validation)
S3method(print,gp3bayes_sensitivity_plan)
S3method(print,gp3bayes_sensitivity_suite)
S3method(print,gp3bayes_separation_screen)
S3method(print,gp3bayes_strict_readiness_audit)
S3method(print,gp3bayes_transformation_recipe)
S3method(print,gp3bayes_transformation_replay_audit)
S3method(print,gp3bayes_workflow_status)
export(advanced_pupil_trajectory_table)
export(analysis_bundle_table)
export(analysis_manifest_table)
export(apply_transformation_recipe)
export(as_pupil_prediction_draws)
export(assess_binary_prior_sensitivity)
export(assess_duration_prior_sensitivity)
export(assess_powerscaled_sensitivity)
export(audit_advanced_pupil_identifiability)
export(audit_backend_parity)
export(audit_binocular_pupil_readiness)
export(audit_design_support)
export(audit_duration_boundaries)
export(audit_duration_unit_invariance)
export(audit_estimand_invariance)
export(audit_fixed_effect_design)
export(audit_missingness_structure)
export(audit_model_readiness)
export(audit_model_readiness_strict)
export(audit_prediction_support)
export(audit_pupil_computational_budget)
export(audit_pupil_measurement_context)
export(audit_pupil_measurement_model)
export(audit_pupil_missingness)
export(audit_pupil_predictive_calibration)
export(audit_pupil_readiness)
export(audit_pupil_temporal_dependence)
export(audit_random_effects_support)
export(backend_capabilities)
export(backend_environment_table)
export(backend_parity_table)
export(bayesian_backend_capabilities)
export(binary_calibration_error)
export(binary_calibration_table)
export(binary_calibration_uncertainty)
export(binary_calibration_uncertainty_table)
export(binary_confusion_table)
export(binary_group_calibration)
export(binary_precision_recall_curve)
export(binary_prediction_scores)
export(binary_roc_curve)
export(binary_threshold_metrics)
export(build_model_formula)
export(capture_gp3bayes_schema)
export(check_advanced_pupil_prior_predictive)
export(check_binary_posterior_predictive)
export(check_binary_ppc_details)
export(check_binary_prior_predictive)
export(check_cmdstan_backend)
export(check_duration_posterior_predictive)
export(check_duration_ppc_details)
export(check_duration_prior_predictive)
export(check_model_ppc)
export(check_pupil_posterior_predictive)
export(check_pupil_prior_predictive)
export(collect_model_evidence)
export(compare_analysis_manifests)
export(compare_estimand_sensitivity)
export(compare_gp3bayes_schemas)
export(compare_psis_loo)
export(compare_pupil_autocorrelation)
export(compare_pupil_lfo)
export(compare_pupil_models)
export(compare_pupil_sensitivity_estimands)
export(compute_kfold_cv)
export(compute_loo_model_weights)
export(compute_psis_loo)
export(compute_psis_loo_from_log_lik)
export(create_advanced_pupil_prior_specification)
export(create_analysis_bundle)
export(create_analysis_figure_set)
export(create_analysis_manifest)
export(create_binary_model_report)
export(create_brms_sbc_plan)
export(create_complete_evidence_inventory)
export(create_contrast_coding_sensitivity_specification)
export(create_custom_sbc_plan)
export(create_diagnostic_dashboard)
export(create_diagnostic_dashboard_figures)
export(create_duration_model_report)
export(create_duration_unit_sensitivity_specification)
export(create_figure_set)
export(create_group_deletion_sensitivity_plan)
export(create_loo_influence_atlas)
export(create_model_card)
export(create_model_contract)
export(create_model_evidence_report)
export(create_model_specification)
export(create_prediction_contrast_profile)
export(create_prediction_grid)
export(create_prediction_profile)
export(create_prediction_surface)
export(create_predictive_distribution_atlas)
export(create_predictor_scaling_sensitivity_specification)
export(create_prior_specification)
export(create_publication_registry)
export(create_publication_table_set)
export(create_pupil_advanced_sensitivity_suite)
export(create_pupil_arma_spec)
export(create_pupil_contract)
export(create_pupil_gp_spec)
export(create_pupil_lfo_plan)
export(create_pupil_measurement_model)
export(create_pupil_missingness_spec)
export(create_pupil_model_set)
export(create_pupil_sensitivity_suite)
export(create_pupil_validation_plan)
export(create_random_slope_sensitivity_plan)
export(create_reporting_checklist)
export(create_sensitivity_suite_plan)
export(create_transformation_recipe)
export(design_support_table)
export(detect_binary_separation)
export(diagnose_advanced_pupil_fit)
export(diagnose_binary_fit)
export(diagnose_duration_fit)
export(diagnose_model_fit)
export(diagnose_pupil_fit)
export(diagnostic_dashboard_table)
export(duration_pit_table)
export(duration_prediction_scores)
export(duration_qq_table)
export(duration_quantile_calibration)
export(duration_tail_check)
export(estimand_sensitivity_table)
export(estimate_binocular_pupil_trajectory)
export(estimate_model_estimands)
export(estimate_pupil_auc)
export(estimate_pupil_dynamic_contrast)
export(estimate_pupil_peak)
export(estimate_pupil_peak_latency)
export(estimate_pupil_residual_scale)
export(estimate_pupil_response_parameters)
export(estimate_pupil_threshold_duration)
export(estimate_pupil_trajectory)
export(estimate_pupil_trajectory_derivative)
export(estimate_pupil_window)
export(estimate_standardized_duration_estimands)
export(estimate_standardized_probability_contrast)
export(evaluate_pathological_simulation)
export(evidence_inventory_table)
export(extract_expected_predictions)
export(extract_linear_predictions)
export(extract_log_likelihood)
export(extract_posterior_draws)
export(extract_posterior_predictions)
export(extract_sampler_diagnostics)
export(fit_advanced_pupil_model)
export(fit_advanced_pupil_model_backend)
export(fit_advanced_pupil_model_cmdstanr)
export(fit_binary_model)
export(fit_binary_model_backend)
export(fit_binary_model_cmdstanr)
export(fit_binocular_pupil_model)
export(fit_duration_model)
export(fit_duration_model_backend)
export(fit_duration_model_cmdstanr)
export(fit_pupil_model)
export(fit_pupil_model_backend)
export(fit_pupil_model_cmdstanr)
export(fit_pupil_response_shape_model)
export(freeze_analysis_manifest)
export(freeze_gp3bayes_schema)
export(gazepoint_pupil_mapping_table)
export(gp3bayes_specification_traceability)
export(group_deletion_sensitivity_table)
export(group_effect_draws_table)
export(group_effect_rank_probability_table)
export(group_effect_table)
export(group_prediction_summary)
export(grouped_prediction_check)
export(identify_identifier_like_predictors)
export(identify_loo_influential_observations)
export(identify_mcmc_issues)
export(inspect_gazepoint_pupil_schema)
export(interaction_prior_summary)
export(invert_transformation_recipe)
export(loo_diagnostic_table)
export(loo_flagged_data)
export(loo_group_influence_table)
export(loo_influence_atlas_table)
export(loo_influence_summary)
export(loo_pointwise_table)
export(loo_summary_table)
export(manifest_comparison_table)
export(materialize_pupil_advanced_sensitivity_scenario)
export(materialize_pupil_sensitivity_scenario)
export(mcmc_diagnostic_table)
export(missingness_audit_table)
export(model_card_table)
export(model_comparison_table)
export(model_evidence_table)
export(model_weights_table)
export(model_workflow_status)
export(plot_advanced_pupil_simulation)
export(plot_advanced_pupil_trajectory)
export(plot_autocorrelation)
export(plot_backend_environment_gg)
export(plot_backend_parity_gg)
export(plot_binary_calibration)
export(plot_binary_calibration_uncertainty)
export(plot_binary_group_calibration)
export(plot_binary_precision_recall)
export(plot_binary_roc)
export(plot_binary_threshold_metrics)
export(plot_binocular_pupil_trajectory)
export(plot_design_support_gg)
export(plot_diagnostic_dashboard)
export(plot_duration_pit)
export(plot_duration_qq)
export(plot_duration_quantile_calibration)
export(plot_duration_tail)
export(plot_estimand_intervals)
export(plot_estimand_sensitivity_gg)
export(plot_exceedance_probability)
export(plot_group_deletion_sensitivity)
export(plot_group_effect_distribution)
export(plot_group_effect_rank_probability)
export(plot_group_effects)
export(plot_group_predictions)
export(plot_grouped_prediction_check)
export(plot_loo_group_elpd)
export(plot_loo_group_influence)
export(plot_loo_influence)
export(plot_loo_influence_rank)
export(plot_loo_pareto_vs_elpd)
export(plot_loo_pointwise_elpd)
export(plot_manifest_comparison_gg)
export(plot_mcmc_quality)
export(plot_missingness_gg)
export(plot_model_comparison)
export(plot_model_evidence_gg)
export(plot_model_weights)
export(plot_posterior_areas)
export(plot_posterior_correlations)
export(plot_posterior_density)
export(plot_posterior_intervals)
export(plot_posterior_pairs)
export(plot_powerscale_sensitivity_gg)
export(plot_ppc_statistic)
export(plot_prediction_contrast_profile)
export(plot_prediction_draws)
export(plot_prediction_gradient)
export(plot_prediction_interval_width)
export(plot_prediction_intervals)
export(plot_prediction_profile)
export(plot_prediction_rank_probabilities)
export(plot_prediction_score_uncertainty)
export(plot_prediction_support)
export(plot_prediction_surface)
export(plot_prediction_surface_uncertainty)
export(plot_predictive_atlas_statistics)
export(plot_predictive_coverage)
export(plot_predictive_quantile_envelope)
export(plot_predictive_residuals)
export(plot_prior_posterior_contraction)
export(plot_prior_posterior_density)
export(plot_prior_posterior_intervals)
export(plot_prior_posterior_shift)
export(plot_prior_sensitivity)
export(plot_prior_sensitivity_scenarios)
export(plot_pupil_autocorrelation_comparison)
export(plot_pupil_dynamic_contrast)
export(plot_pupil_estimand)
export(plot_pupil_gp_hyperparameters)
export(plot_pupil_identifiability_audit)
export(plot_pupil_lfo)
export(plot_pupil_measurement_audit)
export(plot_pupil_measurement_uncertainty)
export(plot_pupil_missingness)
export(plot_pupil_model_comparison)
export(plot_pupil_model_complexity)
export(plot_pupil_observed_trajectory)
export(plot_pupil_posterior_trajectory)
export(plot_pupil_ppc)
export(plot_pupil_predictive_calibration)
export(plot_pupil_readiness)
export(plot_pupil_residual_acf)
export(plot_pupil_residual_scale)
export(plot_pupil_residual_spectrum)
export(plot_pupil_response_parameters)
export(plot_pupil_sensitivity)
export(plot_pupil_temporal_dependence)
export(plot_pupil_trajectory_derivative)
export(plot_pupil_validation)
export(plot_random_intercept_variance_partition)
export(plot_random_slope_sensitivity)
export(plot_rank_diagnostics)
export(plot_recovery_bias)
export(plot_recovery_coverage)
export(plot_recovery_estimates)
export(plot_recovery_fit_status)
export(plot_recovery_rmse)
export(plot_reporting_checklist)
export(plot_sampler_diagnostics)
export(plot_sampling_diagnostics)
export(plot_sbc_coverage_gg)
export(plot_sbc_ecdf_gg)
export(plot_sbc_rank_gg)
export(plot_sbc_simulated_vs_estimated_gg)
export(plot_schema_comparison_gg)
export(plot_sensitivity_suite_gg)
export(plot_uncertainty_decomposition)
export(plot_variance_components)
export(posterior_correlation_table)
export(posterior_interval_table)
export(posterior_predictive_statistic)
export(posterior_predictive_summary_table)
export(posterior_probability_table)
export(powerscale_sensitivity_table)
export(powerscale_sequence_for_fit)
export(ppc_statistic_table)
export(predict_advanced_pupil_trajectory)
export(predict_binary_probability)
export(predict_duration)
export(predict_model)
export(predict_pupil_trajectory)
export(prediction_contrast)
export(prediction_contrast_profile_table)
export(prediction_draws_long)
export(prediction_exceedance_probability)
export(prediction_gradient_table)
export(prediction_interval_width)
export(prediction_pairwise_contrasts)
export(prediction_profile_table)
export(prediction_rank_probabilities)
export(prediction_score_uncertainty)
export(prediction_score_uncertainty_table)
export(prediction_support_table)
export(prediction_surface_table)
export(prediction_table)
export(prediction_uncertainty_decomposition)
export(predictive_coverage_table)
export(predictive_distribution_atlas_table)
export(predictive_quantile_envelope)
export(predictive_residuals)
export(preflight_model_specification)
export(prepare_binocular_pupil_timecourse)
export(prepare_hierarchical_binary_data)
export(prepare_hierarchical_duration_data)
export(prepare_pupil_timecourse)
export(prior_posterior_bridge)
export(prior_posterior_distance_table)
export(prior_posterior_draws_long)
export(prior_posterior_summary_table)
export(prior_sensitivity_scenario_table)
export(prior_sensitivity_table)
export(prior_specification_table)
export(publication_registry_table)
export(pupil_advanced_capabilities)
export(pupil_advanced_compatibility_table)
export(pupil_advanced_mapping_table)
export(pupil_advanced_specification_table)
export(pupil_autocorrelation_table)
export(pupil_binocular_agreement_table)
export(pupil_binocular_correlation)
export(pupil_binocular_difference)
export(pupil_condition_contrast)
export(pupil_distribution_table)
export(pupil_dynamic_contrast_table)
export(pupil_gp_hyperparameters)
export(pupil_gp_table)
export(pupil_identifiability_table)
export(pupil_measurement_audit_table)
export(pupil_measurement_uncertainty_table)
export(pupil_missingness_table)
export(pupil_model_card)
export(pupil_model_card_table)
export(pupil_model_comparison_table)
export(pupil_model_weights)
export(pupil_ppc_table)
export(pupil_readiness_table)
export(pupil_residual_acf)
export(pupil_residual_scale_table)
export(pupil_residual_spectrum)
export(pupil_response_parameter_table)
export(pupil_sensitivity_table)
export(pupil_specification_table)
export(pupil_trajectory_derivative_table)
export(pupil_trajectory_table)
export(pupil_validation_table)
export(random_intercept_variance_partition)
export(random_intercept_variance_partition_table)
export(random_slope_sensitivity_table)
export(read_analysis_manifest)
export(read_gp3bayes_schema)
export(recovery_estimate_table)
export(recovery_fit_status_table)
export(recovery_parameter_table)
export(register_publication_figure)
export(register_publication_table)
export(review_duration_extremes)
export(run_binary_recovery)
export(run_duration_recovery)
export(run_group_deletion_sensitivity)
export(run_random_slope_sensitivity)
export(run_sbc_plan)
export(run_sensitivity_suite)
export(sampler_diagnostic_table)
export(save_figure_set)
export(save_publication_registry_figures)
export(sbc_overview_table)
export(sbc_stats_table)
export(schema_comparison_table)
export(score_pupil_predictions)
export(sensitivity_suite_table)
export(simulate_advanced_pupil_timecourse)
export(simulate_binary_pathology)
export(simulate_binocular_pupil_timecourse)
export(simulate_declared_prior_draws)
export(simulate_duration_pathology)
export(simulate_hierarchical_binary_data)
export(simulate_hierarchical_duration_data)
export(simulate_pupil_response_shape)
export(simulate_pupil_timecourse)
export(specify_advanced_pupil_timecourse_model)
export(specify_binary_model)
export(specify_binary_model_with_interaction_prior)
export(specify_binocular_pupil_model)
export(specify_duration_model)
export(specify_duration_model_with_interaction_prior)
export(specify_pupil_distribution)
export(specify_pupil_response_shape_model)
export(specify_pupil_timecourse_model)
export(summarise_binary_group_variation)
export(summarise_binary_posterior)
export(summarise_condition_balance)
export(summarise_duration_posterior)
export(summarise_estimand_draws)
export(summarise_mcmc_quality)
export(summarise_model_posterior)
export(summarise_pupil_posterior)
export(summarise_sbc_result)
export(summarise_sensitivity_suite)
export(theme_gp3bayes)
export(translate_advanced_pupil_model_to_brms)
export(translate_binary_model_to_brms)
export(translate_binary_model_with_interaction_prior)
export(translate_binocular_pupil_model_to_brms)
export(translate_duration_model_to_brms)
export(translate_duration_model_with_interaction_prior)
export(translate_pupil_model_to_brms)
export(translate_pupil_response_shape_to_brms)
export(validate_analysis_manifest)
export(validate_backend_environment)
export(validate_gp3bayes_object)
export(validate_gp3bayes_schema)
export(validate_prior_specification)
export(validate_publication_registry)
export(validate_pupil_leave_future_out)
export(validate_pupil_model)
export(validate_transformation_replay)
export(variance_component_table)
export(write_analysis_bundle_report)
export(write_diagnostic_dashboard_report)
export(write_model_card)
export(write_publication_registry)
export(write_reproducibility_report)
