## ----setup, include=FALSE-----------------------------------------------------
knitr::opts_chunk$set(collapse = TRUE, comment = "#>")

## ----eval=FALSE---------------------------------------------------------------
# bundle <- create_analysis_bundle(
#   fit,
#   ndraws = 1000,
#   include_group_effects = FALSE,
#   include_loo = TRUE
# )
# 
# analysis_bundle_table(bundle)
# 
# tables <- create_publication_table_set(bundle)
# figures <- create_analysis_figure_set(bundle)

## ----eval=FALSE---------------------------------------------------------------
# write_analysis_bundle_report(
#   bundle,
#   file = file.path(tempdir(), "gp3bayes-analysis.md")
# )
# 
# save_figure_set(
#   figures,
#   directory = file.path(tempdir(), "gp3bayes-figures"),
#   device = "png"
# )

