## ----setup, include=FALSE-----------------------------------------------------
knitr::opts_chunk$set(collapse = TRUE, comment = "#>")

## -----------------------------------------------------------------------------
library(gp3bayes)

draws <- cbind(
  intercept = seq(-1, 1, length.out = 500),
  condition = seq(-0.5, 0.7, length.out = 500)
)

posterior_interval_table(draws)
posterior_probability_table(draws, rope = c(-0.1, 0.1))
posterior_correlation_table(draws)

## ----eval=requireNamespace("ggplot2", quietly=TRUE) && requireNamespace("bayesplot", quietly=TRUE)----
plot_posterior_intervals(draws)
plot_posterior_areas(draws)

## ----eval=FALSE---------------------------------------------------------------
# draw_array <- extract_posterior_draws(fit, regex = "^b_", format = "array")
# draw_df <- extract_posterior_draws(fit, regex = "^b_", format = "df")
# 
# mcmc_diagnostic_table(fit)
# sampler_diagnostic_table(fit)
# quality <- summarise_mcmc_quality(fit)
# 
# plot_rank_diagnostics(fit)
# plot_autocorrelation(fit)
# plot_mcmc_quality(quality)
# plot_sampler_diagnostics(fit)

