## ----setup, include=FALSE-----------------------------------------------------
knitr::opts_chunk$set(collapse = TRUE, comment = "#>")

## ----eval=FALSE---------------------------------------------------------------
# recovery_parameter_table(recovery)
# recovery_estimate_table(recovery)
# recovery_fit_status_table(recovery)
# 
# plot_recovery_bias(recovery)
# plot_recovery_coverage(recovery)
# plot_recovery_rmse(recovery)
# plot_recovery_estimates(recovery)
# plot_recovery_fit_status(recovery)

