## ----setup, include=FALSE-----------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)

## ----binary-sensitivity, eval=FALSE-------------------------------------------
# binary_sensitivity <- assess_binary_prior_sensitivity(
#   binary_fit,
#   scale_multipliers = c(
#     tighter = 0.5,
#     wider = 2
#   ),
#   maximum_standardized_shift = 0.25,
#   review_standardized_shift = 0.50
# )
# 
# binary_sensitivity
# binary_sensitivity$comparison

## ----duration-sensitivity, eval=FALSE-----------------------------------------
# duration_sensitivity <- assess_duration_prior_sensitivity(
#   duration_fit,
#   scale_multipliers = c(
#     tighter = 0.5,
#     wider = 2
#   )
# )

## ----binary-recovery, eval=FALSE----------------------------------------------
# binary_recovery <- run_binary_recovery(
#   repetitions = 20,
#   n_participants = 30,
#   trials_per_participant = 16,
#   seed = 5001
# )

## ----duration-recovery, eval=FALSE--------------------------------------------
# duration_recovery <- run_duration_recovery(
#   repetitions = 20,
#   n_participants = 30,
#   trials_per_participant = 16,
#   baseline_median = 500,
#   outcome_unit = "milliseconds",
#   seed = 6001
# )

