## ----setup, include=FALSE-----------------------------------------------------
knitr::opts_chunk$set(collapse = TRUE, comment = "#>")

## ----eval=FALSE---------------------------------------------------------------
# atlas <- create_loo_influence_atlas(
#   loo_result,
#   data = fit$specification$prepared$data
# )
# 
# loo_influence_summary(atlas$table)
# loo_flagged_data(atlas$table)
# 
# plot_loo_pointwise_elpd(atlas$table)
# plot_loo_pareto_vs_elpd(atlas$table)
# plot_loo_influence_rank(atlas$table)

