## ----setup, include=FALSE-----------------------------------------------------
knitr::opts_chunk$set(collapse = TRUE, comment = "#>")

## ----eval=FALSE---------------------------------------------------------------
# grid <- create_prediction_grid(
#   fit,
#   at = list(condition = c("control", "treatment"))
# )
# 
# pred <- predict_model(
#   fit,
#   newdata = grid,
#   type = "expected",
#   include_group_effects = FALSE
# )
# 
# prediction_pairwise_contrasts(pred)
# prediction_interval_width(pred)
# prediction_rank_probabilities(pred)

## ----eval=FALSE---------------------------------------------------------------
# grouped <- group_prediction_summary(pred, by = "condition")
# grouped
# plot_group_predictions(grouped, "condition")

