## ----setup, include=FALSE-----------------------------------------------------
knitr::opts_chunk$set(collapse = TRUE, comment = "#>")

## ----eval=FALSE---------------------------------------------------------------
# sbc_overview_table(result)
# sbc_stats_table(result)
# 
# plot_sbc_rank_gg(result)
# plot_sbc_ecdf_gg(result)
# plot_sbc_coverage_gg(result)
# plot_sbc_simulated_vs_estimated_gg(result)

