## ----setup, include=FALSE-----------------------------------------------------
knitr::opts_chunk$set(collapse = TRUE, comment = "#>")

## ----eval=FALSE---------------------------------------------------------------
# bridge <- prior_posterior_bridge(fit)
# 
# prior_posterior_summary_table(bridge)
# prior_posterior_distance_table(bridge)
# 
# plot_prior_posterior_density(bridge)
# plot_prior_posterior_intervals(bridge)
# plot_prior_posterior_shift(bridge)
# plot_prior_posterior_contraction(bridge)

