## ----setup, include=FALSE-----------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>",
  fig.width = 7,
  fig.height = 4.5
)
library(gp3bayes)

## ----ppc-concept, eval=FALSE--------------------------------------------------
# ppc <- check_pupil_posterior_predictive(
#   pupil_fit,
#   ndraws = 200,
#   window = c(0.3, 1.0)
# )
# pupil_ppc_table(ppc)
# plot_pupil_ppc(ppc)

## ----residual-concept, eval=FALSE---------------------------------------------
# diag <- diagnose_pupil_fit(pupil_fit)
# as.data.frame(diag)
# acf_table <- pupil_residual_acf(pupil_fit, max_lag = 12)
# head(acf_table)
# plot_pupil_residual_acf(acf_table)

