## ----setup, include=FALSE-----------------------------------------------------
knitr::opts_chunk$set(collapse = TRUE, comment = "#>")

## ----eval=FALSE---------------------------------------------------------------
# registry <- create_publication_registry("Primary analysis")
# registry <- register_publication_table(
#   registry,
#   "posterior",
#   posterior_interval_table(fit),
#   caption = "Posterior summaries",
#   source = "primary fit"
# )
# registry <- register_publication_figure(
#   registry,
#   "posterior_intervals",
#   plot_posterior_intervals(fit)
# )
# 
# validate_publication_registry(registry)
# publication_registry_table(registry)

## ----eval=FALSE---------------------------------------------------------------
# dashboard <- create_diagnostic_dashboard(
#   fit = fit,
#   model_card = card,
#   loo = loo_atlas,
#   prior_posterior = bridge,
#   sensitivity = sensitivity,
#   recovery = recovery,
#   sbc = sbc_result
# )
# 
# diagnostic_dashboard_table(dashboard)
# plot_diagnostic_dashboard(dashboard)
# create_diagnostic_dashboard_figures(dashboard)

