## ----setup, include=FALSE-----------------------------------------------------
knitr::opts_chunk$set(collapse = TRUE, comment = "#>")

## ----eval=FALSE---------------------------------------------------------------
# effects <- group_effect_table(fit)
# components <- variance_component_table(fit)
# 
# plot_group_effects(effects)
# plot_variance_components(components)

## ----eval=FALSE---------------------------------------------------------------
# participant_ppc <- grouped_prediction_check(
#   fit,
#   group = "participant_id",
#   ndraws = 1000
# )
# 
# as.data.frame(participant_ppc)
# plot_grouped_prediction_check(participant_ppc)

## ----eval=FALSE---------------------------------------------------------------
# uncertainty <- prediction_uncertainty_decomposition(
#   fit,
#   include_group_effects = FALSE,
#   ndraws = 1000
# )
# 
# as.data.frame(uncertainty)
# plot_uncertainty_decomposition(uncertainty)

