## ----setup, include=FALSE-----------------------------------------------------
knitr::opts_chunk$set(collapse = TRUE, comment = "#>")

## ----eval=FALSE---------------------------------------------------------------
# loo_result <- compute_psis_loo(fit, cores = 1)
# 
# loo_summary_table(loo_result)
# loo_diagnostic_table(loo_result)
# plot_loo_influence(loo_result)

## ----eval=FALSE---------------------------------------------------------------
# comparison <- compare_psis_loo(
#   list(reference = fit_reference, sensitivity = fit_sensitivity),
#   cores = 1
# )
# 
# weights <- compute_loo_model_weights(comparison, method = "stacking")
# 
# model_comparison_table(comparison)
# model_weights_table(weights)
# 
# plot_model_comparison(comparison)
# plot_model_weights(weights)

