## ----setup, include=FALSE-----------------------------------------------------
knitr::opts_chunk$set(collapse = TRUE, comment = "#>")

## ----eval=FALSE---------------------------------------------------------------
# bundle <- create_analysis_bundle(
#   fit,
#   ndraws = 1000,
#   include_loo = TRUE
# )
# 
# manifest <- create_analysis_manifest(
#   fit = fit,
#   estimands = "primary"
# )
# 
# card <- create_model_card(
#   fit,
#   analysis_bundle = bundle,
#   manifest = manifest,
#   label = "Primary confirmatory model"
# )
# 
# model_card_table(card)
# checklist <- create_reporting_checklist(card)
# plot_reporting_checklist(checklist)

## ----eval=FALSE---------------------------------------------------------------
# write_model_card(
#   card,
#   file = file.path(tempdir(), "gp3bayes-model-card.md")
# )

