## ----setup, include=FALSE-----------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)

## ----diagnostic-plots, eval=FALSE---------------------------------------------
# plot_sampling_diagnostics(
#   binary_fit,
#   type = "trace"
# )
# 
# plot_sampling_diagnostics(
#   binary_fit,
#   type = "energy"
# )
# 
# plot_sampling_diagnostics(
#   binary_fit,
#   type = "treedepth"
# )
# 
# plot_sampling_diagnostics(
#   binary_fit,
#   type = "divergence"
# )

