---
title: "Complete Public API Map"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{Complete Public API Map}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r setup, include=FALSE}
knitr::opts_chunk$set(collapse = TRUE, comment = "#>")
```

This article is a discoverability index for the frozen development API. It groups every exported function by its primary interface role. Function names are linked by pkgdown to their full reference documentation. The map is not a recommendation to call every low-level adapter directly.

**Frozen development API size:** 324 exported functions.

## Audits

- `audit_backend_parity()`
- `audit_design_support()`
- `audit_duration_boundaries()`
- `audit_duration_unit_invariance()`
- `audit_estimand_invariance()`
- `audit_fixed_effect_design()`
- `audit_missingness_structure()`
- `audit_model_readiness()`
- `audit_model_readiness_strict()`
- `audit_prediction_support()`
- `audit_random_effects_support()`

## Checks

- `check_binary_posterior_predictive()`
- `check_binary_ppc_details()`
- `check_binary_prior_predictive()`
- `check_cmdstan_backend()`
- `check_duration_posterior_predictive()`
- `check_duration_ppc_details()`
- `check_duration_prior_predictive()`
- `check_model_ppc()`

## Constructors and bundles

- `create_analysis_bundle()`
- `create_analysis_figure_set()`
- `create_analysis_manifest()`
- `create_binary_model_report()`
- `create_brms_sbc_plan()`
- `create_complete_evidence_inventory()`
- `create_contrast_coding_sensitivity_specification()`
- `create_custom_sbc_plan()`
- `create_diagnostic_dashboard()`
- `create_diagnostic_dashboard_figures()`
- `create_duration_model_report()`
- `create_duration_unit_sensitivity_specification()`
- `create_figure_set()`
- `create_group_deletion_sensitivity_plan()`
- `create_loo_influence_atlas()`
- `create_model_card()`
- `create_model_contract()`
- `create_model_evidence_report()`
- `create_model_specification()`
- `create_prediction_contrast_profile()`
- `create_prediction_grid()`
- `create_prediction_profile()`
- `create_prediction_surface()`
- `create_predictive_distribution_atlas()`
- `create_predictor_scaling_sensitivity_specification()`
- `create_prior_specification()`
- `create_publication_registry()`
- `create_publication_table_set()`
- `create_random_slope_sensitivity_plan()`
- `create_reporting_checklist()`
- `create_sensitivity_suite_plan()`
- `create_transformation_recipe()`

## Execution workflows

- `run_binary_recovery()`
- `run_duration_recovery()`
- `run_group_deletion_sensitivity()`
- `run_random_slope_sensitivity()`
- `run_sbc_plan()`
- `run_sensitivity_suite()`

## Explicit writers

- `write_analysis_bundle_report()`
- `write_diagnostic_dashboard_report()`
- `write_model_card()`
- `write_publication_registry()`
- `write_reproducibility_report()`

## Extraction

- `extract_expected_predictions()`
- `extract_linear_predictions()`
- `extract_log_likelihood()`
- `extract_posterior_draws()`
- `extract_posterior_predictions()`
- `extract_sampler_diagnostics()`

## Freezing and reproducibility

- `freeze_analysis_manifest()`
- `freeze_gp3bayes_schema()`

## Model fitting

- `fit_binary_model()`
- `fit_binary_model_backend()`
- `fit_binary_model_cmdstanr()`
- `fit_duration_model()`
- `fit_duration_model_backend()`
- `fit_duration_model_cmdstanr()`

## Other public workflows

- `apply_transformation_recipe()`
- `assess_binary_prior_sensitivity()`
- `assess_duration_prior_sensitivity()`
- `assess_powerscaled_sensitivity()`
- `backend_capabilities()`
- `bayesian_backend_capabilities()`
- `binary_calibration_error()`
- `binary_calibration_uncertainty()`
- `binary_group_calibration()`
- `binary_precision_recall_curve()`
- `binary_prediction_scores()`
- `binary_roc_curve()`
- `binary_threshold_metrics()`
- `build_model_formula()`
- `capture_gp3bayes_schema()`
- `collect_model_evidence()`
- `compare_analysis_manifests()`
- `compare_estimand_sensitivity()`
- `compare_gp3bayes_schemas()`
- `compare_psis_loo()`
- `compute_kfold_cv()`
- `compute_loo_model_weights()`
- `compute_psis_loo()`
- `compute_psis_loo_from_log_lik()`
- `detect_binary_separation()`
- `diagnose_binary_fit()`
- `diagnose_duration_fit()`
- `diagnose_model_fit()`
- `duration_prediction_scores()`
- `duration_quantile_calibration()`
- `duration_tail_check()`
- `estimate_model_estimands()`
- `estimate_standardized_duration_estimands()`
- `estimate_standardized_probability_contrast()`
- `evaluate_pathological_simulation()`
- `gp3bayes_specification_traceability()`
- `group_prediction_summary()`
- `grouped_prediction_check()`
- `identify_identifier_like_predictors()`
- `identify_loo_influential_observations()`
- `identify_mcmc_issues()`
- `interaction_prior_summary()`
- `invert_transformation_recipe()`
- `loo_flagged_data()`
- `loo_influence_summary()`
- `model_workflow_status()`
- `posterior_predictive_statistic()`
- `powerscale_sequence_for_fit()`
- `preflight_model_specification()`
- `prepare_hierarchical_binary_data()`
- `prepare_hierarchical_duration_data()`
- `prior_posterior_bridge()`
- `prior_posterior_draws_long()`
- `random_intercept_variance_partition()`
- `register_publication_figure()`
- `review_duration_extremes()`
- `save_figure_set()`
- `save_publication_registry_figures()`
- `specify_binary_model()`
- `specify_binary_model_with_interaction_prior()`
- `specify_duration_model()`
- `specify_duration_model_with_interaction_prior()`
- `theme_gp3bayes()`
- `translate_binary_model_to_brms()`
- `translate_binary_model_with_interaction_prior()`
- `translate_duration_model_to_brms()`
- `translate_duration_model_with_interaction_prior()`

## Plots and graphics

- `plot_autocorrelation()`
- `plot_backend_environment_gg()`
- `plot_backend_parity_gg()`
- `plot_binary_calibration()`
- `plot_binary_calibration_uncertainty()`
- `plot_binary_group_calibration()`
- `plot_binary_precision_recall()`
- `plot_binary_roc()`
- `plot_binary_threshold_metrics()`
- `plot_design_support_gg()`
- `plot_diagnostic_dashboard()`
- `plot_duration_pit()`
- `plot_duration_qq()`
- `plot_duration_quantile_calibration()`
- `plot_duration_tail()`
- `plot_estimand_intervals()`
- `plot_estimand_sensitivity_gg()`
- `plot_exceedance_probability()`
- `plot_group_deletion_sensitivity()`
- `plot_group_effect_distribution()`
- `plot_group_effect_rank_probability()`
- `plot_group_effects()`
- `plot_group_predictions()`
- `plot_grouped_prediction_check()`
- `plot_loo_group_elpd()`
- `plot_loo_group_influence()`
- `plot_loo_influence()`
- `plot_loo_influence_rank()`
- `plot_loo_pareto_vs_elpd()`
- `plot_loo_pointwise_elpd()`
- `plot_manifest_comparison_gg()`
- `plot_mcmc_quality()`
- `plot_missingness_gg()`
- `plot_model_comparison()`
- `plot_model_evidence_gg()`
- `plot_model_weights()`
- `plot_posterior_areas()`
- `plot_posterior_correlations()`
- `plot_posterior_density()`
- `plot_posterior_intervals()`
- `plot_posterior_pairs()`
- `plot_powerscale_sensitivity_gg()`
- `plot_ppc_statistic()`
- `plot_prediction_contrast_profile()`
- `plot_prediction_draws()`
- `plot_prediction_gradient()`
- `plot_prediction_interval_width()`
- `plot_prediction_intervals()`
- `plot_prediction_profile()`
- `plot_prediction_rank_probabilities()`
- `plot_prediction_score_uncertainty()`
- `plot_prediction_support()`
- `plot_prediction_surface()`
- `plot_prediction_surface_uncertainty()`
- `plot_predictive_atlas_statistics()`
- `plot_predictive_coverage()`
- `plot_predictive_quantile_envelope()`
- `plot_predictive_residuals()`
- `plot_prior_posterior_contraction()`
- `plot_prior_posterior_density()`
- `plot_prior_posterior_intervals()`
- `plot_prior_posterior_shift()`
- `plot_prior_sensitivity()`
- `plot_prior_sensitivity_scenarios()`
- `plot_random_intercept_variance_partition()`
- `plot_random_slope_sensitivity()`
- `plot_rank_diagnostics()`
- `plot_recovery_bias()`
- `plot_recovery_coverage()`
- `plot_recovery_estimates()`
- `plot_recovery_fit_status()`
- `plot_recovery_rmse()`
- `plot_reporting_checklist()`
- `plot_sampler_diagnostics()`
- `plot_sampling_diagnostics()`
- `plot_sbc_coverage_gg()`
- `plot_sbc_ecdf_gg()`
- `plot_sbc_rank_gg()`
- `plot_sbc_simulated_vs_estimated_gg()`
- `plot_schema_comparison_gg()`
- `plot_sensitivity_suite_gg()`
- `plot_uncertainty_decomposition()`
- `plot_variance_components()`

## Prediction

- `predict_binary_probability()`
- `predict_duration()`
- `predict_model()`
- `prediction_contrast()`
- `prediction_draws_long()`
- `prediction_exceedance_probability()`
- `prediction_interval_width()`
- `prediction_pairwise_contrasts()`
- `prediction_rank_probabilities()`
- `prediction_score_uncertainty()`
- `prediction_uncertainty_decomposition()`
- `predictive_quantile_envelope()`
- `predictive_residuals()`

## Readers

- `read_analysis_manifest()`
- `read_gp3bayes_schema()`

## Simulation

- `simulate_binary_pathology()`
- `simulate_declared_prior_draws()`
- `simulate_duration_pathology()`
- `simulate_hierarchical_binary_data()`
- `simulate_hierarchical_duration_data()`

## Summaries

- `summarise_binary_group_variation()`
- `summarise_binary_posterior()`
- `summarise_condition_balance()`
- `summarise_duration_posterior()`
- `summarise_estimand_draws()`
- `summarise_mcmc_quality()`
- `summarise_model_posterior()`
- `summarise_sbc_result()`
- `summarise_sensitivity_suite()`

## Tables and adapters

- `analysis_bundle_table()`
- `analysis_manifest_table()`
- `backend_environment_table()`
- `backend_parity_table()`
- `binary_calibration_table()`
- `binary_calibration_uncertainty_table()`
- `binary_confusion_table()`
- `design_support_table()`
- `diagnostic_dashboard_table()`
- `duration_pit_table()`
- `duration_qq_table()`
- `estimand_sensitivity_table()`
- `evidence_inventory_table()`
- `group_deletion_sensitivity_table()`
- `group_effect_draws_table()`
- `group_effect_rank_probability_table()`
- `group_effect_table()`
- `loo_diagnostic_table()`
- `loo_group_influence_table()`
- `loo_influence_atlas_table()`
- `loo_pointwise_table()`
- `loo_summary_table()`
- `manifest_comparison_table()`
- `mcmc_diagnostic_table()`
- `missingness_audit_table()`
- `model_card_table()`
- `model_comparison_table()`
- `model_evidence_table()`
- `model_weights_table()`
- `posterior_correlation_table()`
- `posterior_interval_table()`
- `posterior_predictive_summary_table()`
- `posterior_probability_table()`
- `powerscale_sensitivity_table()`
- `ppc_statistic_table()`
- `prediction_contrast_profile_table()`
- `prediction_gradient_table()`
- `prediction_profile_table()`
- `prediction_score_uncertainty_table()`
- `prediction_support_table()`
- `prediction_surface_table()`
- `prediction_table()`
- `predictive_coverage_table()`
- `predictive_distribution_atlas_table()`
- `prior_posterior_distance_table()`
- `prior_posterior_summary_table()`
- `prior_sensitivity_scenario_table()`
- `prior_sensitivity_table()`
- `prior_specification_table()`
- `publication_registry_table()`
- `random_intercept_variance_partition_table()`
- `random_slope_sensitivity_table()`
- `recovery_estimate_table()`
- `recovery_fit_status_table()`
- `recovery_parameter_table()`
- `register_publication_table()`
- `sampler_diagnostic_table()`
- `sbc_overview_table()`
- `sbc_stats_table()`
- `schema_comparison_table()`
- `sensitivity_suite_table()`
- `variance_component_table()`

## Validation

- `validate_analysis_manifest()`
- `validate_backend_environment()`
- `validate_gp3bayes_object()`
- `validate_gp3bayes_schema()`
- `validate_prior_specification()`
- `validate_publication_registry()`
- `validate_transformation_replay()`
